# pypi_api_installer
A python library with a set of tools for installing python packages from [PYPI](https://pypi.org/) dynamicly and without using `pip` or any other shell tools.

## installation ⬇️
Use this `pip` command to install the package:
```zsh
pip install pypi_api_installer
```

# usage 🙌